@@ -1,70 +1,70 @@
-( cd opt/kde/lib ; rm -rf libkdeeducore.so.1 )
-( cd opt/kde/lib ; ln -sf libkdeeducore.so.1.2.0 libkdeeducore.so.1 )
-( cd opt/kde/lib ; rm -rf libkdeeducore.so )
-( cd opt/kde/lib ; ln -sf libkdeeducore.so.1.2.0 libkdeeducore.so )
-( cd opt/kde/lib ; rm -rf libkdeeduui.so.3 )
-( cd opt/kde/lib ; ln -sf libkdeeduui.so.3.0.5 libkdeeduui.so.3 )
-( cd opt/kde/lib ; rm -rf libkdeeduui.so )
-( cd opt/kde/lib ; ln -sf libkdeeduui.so.3.0.5 libkdeeduui.so )
-( cd opt/kde/lib ; rm -rf libkdeeduplot.so.1 )
-( cd opt/kde/lib ; ln -sf libkdeeduplot.so.1.2.0 libkdeeduplot.so.1 )
-( cd opt/kde/lib ; rm -rf libkdeeduplot.so )
-( cd opt/kde/lib ; ln -sf libkdeeduplot.so.1.2.0 libkdeeduplot.so )
-( cd opt/kde/lib ; rm -rf libextdate.so.1 )
-( cd opt/kde/lib ; ln -sf libextdate.so.1.2.0 libextdate.so.1 )
-( cd opt/kde/lib ; rm -rf libextdate.so )
-( cd opt/kde/lib ; ln -sf libextdate.so.1.2.0 libextdate.so )
-( cd opt/kde/lib ; rm -rf libkiten.so.1 )
-( cd opt/kde/lib ; ln -sf libkiten.so.1.0.0 libkiten.so.1 )
-( cd opt/kde/lib ; rm -rf libkiten.so )
-( cd opt/kde/lib ; ln -sf libkiten.so.1.0.0 libkiten.so )
-( cd opt/kde/lib ; rm -rf libkvoctraincore.so.0 )
-( cd opt/kde/lib ; ln -sf libkvoctraincore.so.0.0.0 libkvoctraincore.so.0 )
-( cd opt/kde/lib ; rm -rf libkvoctraincore.so )
-( cd opt/kde/lib ; ln -sf libkvoctraincore.so.0.0.0 libkvoctraincore.so )
-( cd opt/kde/bin ; rm -rf lx200classic )
-( cd opt/kde/bin ; ln -sf lx200generic lx200classic )
-( cd opt/kde/bin ; rm -rf lx200autostar )
-( cd opt/kde/bin ; ln -sf lx200generic lx200autostar )
-( cd opt/kde/bin ; rm -rf lx200_16 )
-( cd opt/kde/bin ; ln -sf lx200generic lx200_16 )
-( cd opt/kde/bin ; rm -rf lx200gps )
-( cd opt/kde/bin ; ln -sf lx200generic lx200gps )
-( cd opt/kde/share/doc/HTML/en/kanagram ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kanagram ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/klatin ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/klatin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/blinken ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/blinken ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/khangman ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/khangman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kpercentage ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kpercentage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kturtle ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kturtle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/keduca ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/keduca ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/klettres ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/klettres ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ktouch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ktouch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kwordquiz ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kgeography ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kgeography ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kvoctrain ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kmplot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmplot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kstars ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kstars ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kiten ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kiten ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kig ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kverbos ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kverbos ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kalzium ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kanagram ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kanagram ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kbruch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kbruch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kgeography ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/khangman ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/khangman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kig ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kiten ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/klettres ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/klettres ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kmplot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kpercentage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kpercentage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kstars ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ktouch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ktouch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/parley ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/parley ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/marble ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/marble ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kalgebra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kalgebra ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/step ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/step ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkeduvocdocument.so )
+( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4 libkeduvocdocument.so )
+( cd opt/kde/lib ; rm -rf libkeduvocdocument.so.4 )
+( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4.1.0 libkeduvocdocument.so.4 )
+( cd opt/kde/lib ; rm -rf libkdeeduui.so )
+( cd opt/kde/lib ; ln -sf libkdeeduui.so.4 libkdeeduui.so )
+( cd opt/kde/lib ; rm -rf libkdeeduui.so.4 )
+( cd opt/kde/lib ; ln -sf libkdeeduui.so.4.1.0 libkdeeduui.so.4 )
+( cd opt/kde/lib ; rm -rf libscience.so )
+( cd opt/kde/lib ; ln -sf libscience.so.4 libscience.so )
+( cd opt/kde/lib ; rm -rf libscience.so.4 )
+( cd opt/kde/lib ; ln -sf libscience.so.4.1.0 libscience.so.4 )
+( cd opt/kde/lib ; rm -rf libkiten.so )
+( cd opt/kde/lib ; ln -sf libkiten.so.4 libkiten.so )
+( cd opt/kde/lib ; rm -rf libkiten.so.4 )
+( cd opt/kde/lib ; ln -sf libkiten.so.4.1.0 libkiten.so.4 )
+( cd opt/kde/lib ; rm -rf libsbigudrv.so )
+( cd opt/kde/lib ; ln -sf libsbigudrv.so.1 libsbigudrv.so )
+( cd opt/kde/lib ; rm -rf libsbigudrv.so.1 )
+( cd opt/kde/lib ; ln -sf libsbigudrv.so.1.0.0 libsbigudrv.so.1 )
+( cd opt/kde/lib ; rm -rf libSatLib.so )
+( cd opt/kde/lib ; ln -sf libSatLib.so.4 libSatLib.so )
+( cd opt/kde/lib ; rm -rf libSatLib.so.4 )
+( cd opt/kde/lib ; ln -sf libSatLib.so.4.1.0 libSatLib.so.4 )
+( cd opt/kde/lib ; rm -rf libmarblewidget.so )
+( cd opt/kde/lib ; ln -sf libmarblewidget.so.4 libmarblewidget.so )
+( cd opt/kde/lib ; rm -rf libmarblewidget.so.4 )
+( cd opt/kde/lib ; ln -sf libmarblewidget.so.4.1.0 libmarblewidget.so.4 )
+( cd opt/kde/lib ; rm -rf libanalitza.so )
+( cd opt/kde/lib ; ln -sf libanalitza.so.4 libanalitza.so )
+( cd opt/kde/lib ; rm -rf libanalitza.so.4 )
+( cd opt/kde/lib ; ln -sf libanalitza.so.4.1.0 libanalitza.so.4 )
